<?php
// vim: set ts=4 sw=4 sts=4 et:

/**
 * X-Cart
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the software license agreement
 * that is bundled with this package in the file LICENSE.txt.
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to licensing@x-cart.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not modify this file if you wish to upgrade X-Cart to newer versions
 * in the future. If you wish to customize X-Cart for your needs please
 * refer to http://www.x-cart.com/ for more information.
 *
 * @category  X-Cart 5
 * @author    Qualiteam software Ltd <info@x-cart.com>
 * @copyright Copyright (c) 2011-2013 Qualiteam software Ltd <info@x-cart.com>. All rights reserved
 * @link      http://www.x-cart.com/
 */

namespace XLite\Module\Custom\PreselectFeedMapping\View\FormField\Select;

/**
 * Abstract feed category selector.
 *
 * @LC_Dependencies ("QSL\ProductFeeds")
 */
abstract class ProductField
    extends \XLite\Module\QSL\ProductFeeds\View\FormField\Select\ProductField
    implements \XLite\Base\IDecorator
{
    /**
     * Register JS files.
     *
     * @return array
     */
    public function getJSFiles()
    {
        $list = parent::getJSFiles();
        $list[] = 'modules/Custom/PreselectFeedMapping/product_field.js';

        return $list;
    }

    /**
     * Register CSS files.
     *
     * @return array
     */
    public function getCSSFiles()
    {
        $list = parent::getCSSFiles();
        $list[] = 'modules/Custom/PreselectFeedMapping/product_field.css';

        return $list;
    }

    /**
     * Get text to display as the name of the attribute.
     *
     * @param \XLite\Model\Attribute $attribute Attribute.
     *
     * @return string
     */
    protected function getAttributeName(\XLite\Model\Attribute $attribute)
    {
        if ($attribute) {
            $class = $attribute->getProductClass();
            $product = $attribute->getProduct();
            $name = $attribute->getName();

            return $class
                ? ('"' . $name . '" (class: ' . $class->getName() . ')')
                : ($product
                    ? ('"' . $name . '" (product: ' . $product->getName() . ')')
                    : ('"' . $name . '" (global)')
                );
        } else {
            return '';
        }
    }

    /**
     * Get conditions to search for product attributes.
     *
     * @return \XLite\Core\CommonCell
     */
    protected function getSearchConditions()
    {
        $cnd = parent::getSearchConditions();
        unset($cnd->{\XLite\Model\Repo\Attribute::SEARCH_PRODUCT});

        return $cnd;
    }
}